#!/usr/bin/perl
#
use Test::More qw(no_plan);

use_ok( 'IkiWiki::Plugin::syntax' );

my $text = <<EOF;
#!perl -T

use Test::More;
eval "use Test::Pod 1.14";
plan skip_all => "Test::Pod 1.14 required for testing POD" if $@;
all_pod_files_ok();
EOF

#   initialize the plugin
IkiWiki::Plugin::syntax::checkconfig();

#   Hacking the ikiwiki environment
$IkiWiki::config{srcdir} = '.';

#   Check syntax highlighting from a string
my $result = IkiWiki::Plugin::syntax::preprocess( 
                type        => 'perl',
                description => 't/pod.t',
                text        => $text );

ok($result, 'colorized perl syntax from string');

$result = IkiWiki::Plugin::syntax::preprocess(
                type        =>  'perl',
                description =>  't/pod.t',
                linenumbers =>  1,
                bars        =>  1,
                text        =>  $text );

ok($result, 'colorized perl syntax from numered string');

our %files_and_types = (
    't/pod.t'           =>  'pod',
    'Build.PL'          =>  'perl',
    'META.yml'          =>  undef,
    't/test.conf'       =>  undef,
    't/sarajevo.conf'   =>  undef,
);

#   Check syntax highlighting from files
foreach my $file (keys(%files_and_types)) {
    $result = IkiWiki::Plugin::syntax::preprocess( 
                        file        => $file,
                        description => $file, 
                        page        => $file,
                        defined($files_and_types{$file}) ? 
                            ( type    =>  $files_and_types{$file}) : 
                            ()
                    );

    ok($result, "colorized perl syntax from file ${file}");
}

#   Check syntax highlighting from linenumered files
foreach my $file (qw(t/pod.t Build.PL)) {
    $result = IkiWiki::Plugin::syntax::preprocess( 
                    file        => $file, 
                    linenumbers => 1, 
                    description => $file,
                    page        => $file,                        
                );

    ok($result, "colorized perl syntax from file ${file} (numered)");
}

